@@ -189,6 +189,37 @@ class P100():
 			errorCode = ast.literal_eval(decryptedResponse)["error_code"]
 			errorMessage = self.errorCodes[str(errorCode)]
 
+	def setBrightness(self, brightness):
+		URL = f"http://{self.ipAddress}/app?token={self.token}"
+		Payload = {
+			"method": "set_device_info",
+			"params":{
+				"brightness": brightness
+			},
+			"requestTimeMils": int(round(time.time() * 1000)),
+		}
+
+		headers = {
+			"Cookie": self.cookie
+		}
+
+		EncryptedPayload = self.tpLinkCipher.encrypt(json.dumps(Payload))
+
+		SecurePassthroughPayload = {
+			"method": "securePassthrough",
+			"params":{
+				"request": EncryptedPayload
+			}
+		}
+
+		r = requests.post(URL, json=SecurePassthroughPayload, headers=headers)
+
+		decryptedResponse = self.tpLinkCipher.decrypt(r.json()["result"]["response"])
+
+		if ast.literal_eval(decryptedResponse)["error_code"] != 0:
+			errorCode = ast.literal_eval(decryptedResponse)["error_code"]
+			errorMessage = self.errorCodes[str(errorCode)]
+
 	def turnOff(self):
 		URL = f"http://{self.ipAddress}/app?token={self.token}"
 		Payload = {
@@ -261,4 +292,4 @@ class P100():
 		else:
 			encodedName = data["result"]["nickname"]
 			name = b64decode(encodedName)
-			return name.decode("utf-8")
+			return name.decode("utf-8")
\ No newline at end of file
